@@ -1,11 +1,11 @@
-﻿
-
-
-__version__ = "0.2022.1.6"
 
 
 
-from .GitConfigFile import GitConfigFile
+__author__ = "Jürgen Knauth"
+__version__ = "0.2022.4.10"
+
+
+
 from .AbstractRepositoryFile import AbstractRepositoryFile
 from .GitFileInfo import GitFileInfo
 from .GitCommitHistoryEntry import GitCommitHistoryEntry
@@ -16,3 +16,4 @@ from .GitServerRepository import GitServerRepository
 from .GitWorkingCopy import GitWorkingCopy
 from .GitRemoteRepository import GitRemoteRepository
 
+
